---
title: Gramex Roadmap
...

# Releases

See the [release notes](https://learn.gramener.com/gramex/history.html) for
information about past releases.

Features for the next 2 releases are below. Bugs to be fixed are at the
[issue tracker](http://code.gramener.com/cto/gramex/issues).


# Features

This is a work-in-progress list of features on the Gramex 1.0 roadmap.

## Immediate features

- Twitter streaming: dynamic change of parameters
- Kerberos authentication
- Live reloading of modified Python files
- Better Excel formatting
- DataHandler templates / forms
- Monitoring & logging report usage
- Mechanism to add configuration / settings pages
- Improved test coverage

## App packaging

- App Store

## Caching

- Data caching

## Collaboration

- Commenting
- Workflow
- Editable text annotations (like [teletext.io](https://teletext.io/help/get-started))

## Component gallery

- UI components
- Visualisation components
- Exploratory components
- Analytical components
- Boilerplates

## Configuration management

- User editable configurations and metadata
- Configuration persistence and distributed access

## Content management

- Static data: images, attachments, etc
- Templates for Help pages, blogs, video tutorials, etc
- Content authoring

## Exporting

- Export visual to PDF, PPT, Word, Excel, HTML, PNG
- Export data to Excel, CSV, custom format

## Licensing

- Feature restricted licensing
- License auto generation for specific machines or people
- Clients can issue licenses for end users

## Logging

- Performant asynchronous-flushing key-based logging (e.g. who, what, when, etc)
- Usage tracking: who uses what
- Log file viewer
- Feature tracking: what aspects of Gramex is used more

## Security

- Kerberos authentication
- Role and metadata synchronisation
- User management (add / change / delete users, assign roles, expiry, etc)
- Password management (2FA, forgot password, reset password, expiry, force single session, etc)
- Login tracking (IP, history, device)
- XSRF, XSS, etc

## Decisions

- 9 Jun 2016: Integration with SAML deferred for lack of an easy-to-install SAML
  library on Windows. python-saml (and python3-saml) require `xmlsec` which is
  difficult to install.
